Module random_walk

Module random_walk 

Random walk generation.

Structs

WalkConfig

Functions

generate_biased_walks
generate_biased_walks_from_nodes
Node2Vec-style biased walk generation, restricted to an explicit set of start nodes.
generate_biased_walks_ref
Node2Vec-style biased walk generation for graphs that can return borrowed neighbor slices.
generate_biased_walks_ref_from_nodes
Node2Vec-style biased walk generation, restricted to an explicit set of start nodes.
generate_biased_walks_ref_parallel
Deterministic parallel node2vec-style biased walk generation.
generate_biased_walks_ref_parallel_from_nodes
Deterministic parallel biased walk generation, restricted to an explicit set of start nodes.
generate_biased_walks_ref_streaming_from_nodes
Streaming node2vec-style biased walk generation (borrowed neighbor slices).
generate_walks
generate_walks_from_nodes
Random walk generation (unbiased), but restricted to an explicit set of start nodes.
generate_walks_ref
Random walk generation for graphs that can return borrowed neighbor slices.
generate_walks_ref_from_nodes
Random walk generation (unbiased), but restricted to an explicit set of start nodes.
generate_walks_ref_parallel
Deterministic parallel unbiased walk generation.
generate_walks_ref_parallel_from_nodes
Deterministic parallel unbiased walk generation, restricted to an explicit set of start nodes.
generate_walks_ref_streaming_from_nodes
Streaming unbiased random walk generation (borrowed neighbor slices).
sample_start_nodes_reservoir
Deterministically sample up to k start nodes from 0..node_count.