Minimal graph adapter traits.
Structs
Traits
- Graph
- Graph
Ref - A graph view that can return borrowed neighbor slices.
- Weighted
Graph - Weighted
Graph Ref - A weighted graph view that can return borrowed neighbor + weight slices.
Minimal graph adapter traits.