Module graph

Module graph 

Minimal graph adapter traits.

Structs

AdjacencyMatrix

Traits

Graph
GraphRef
A graph view that can return borrowed neighbor slices.
WeightedGraph
WeightedGraphRef
A weighted graph view that can return borrowed neighbor + weight slices.